package com.rushi.android.vrdemo;

import android.app.Activity;
import android.app.Application;
import android.app.Dialog;
import android.content.Context;

import android.content.DialogInterface;
import android.content.Intent;
import android.net.Uri;
import android.text.TextUtils;
import android.util.Log;
import android.view.KeyEvent;
import android.widget.Toast;

import androidx.appcompat.app.AlertDialog;

import com.rushi.android.vrsdk.RsAppInfo;
import com.rushi.android.vrsdk.RsFinishBlock;
import com.rushi.android.vrsdk.RsBaseShareModel;
import com.rushi.android.vrsdk.RsVrSdk;
import com.rushi.android.vrsdk.RsVrCallBack;


public class App extends Application {

    private static final String OK = "1";
    public static final String TAG = "App";

    @Override
    protected void attachBaseContext(Context base) {
        super.attachBaseContext(base);
        Utils.initSp(this);
    }

    @Override
    public void onCreate() {
        super.onCreate();
        initVr();
    }

    private void initVr() {
        RsVrSdk.setDebug(Utils.isTest());
        // 初始化VR配置及回调
        RsVrSdk.init(this, new RsVrCallBack() {
            @Override
            public RsAppInfo appInfo() {
                return new RsAppInfo() {
                    @Override
                    public String appId() {
                        // 注意正式接入时请联系如视获取正式值
                        return Utils.getAppId();
                    }

                    @Override
                    public String appSecret() {
                        // 注意正式接入时请联系如视获取正式值
                        return Utils.getAppSecret();
                    }

                    @Override
                    public String scheme() {
                        // 可作为应用的app标识使用
                        return "lianjiabeike";
                    }

                    @Override
                    public String userAgent() {
                        return scheme()+"/"+ BuildConfig.VERSION_NAME;
                    }

                    @Override
                    public String wxShareKey() {
                        return "wx97059dc87263b198";
                    }
                };
            }

            @Override
            public void onExitVr() {
                super.onExitVr();
            }

            @Override
            public String accessToken() {
                return Utils.getAccessToken();
            }

            @Override
            public String getUserId() {
                return Utils.getUserId();
            }

            @Override
            public String getUserName() {
                return Utils.getUserName();
            }

            /**
             * 完全自定义分享的实现
             * @param context 上下文
             * @param shareJson 从H5端传递过来的分享实体json
             * @return 返回true代表完全自定义，默认为false
             */
            @Override
            public boolean shareWithParam(Context context, String shareJson) {
                Log.e(TAG,"shareWithParam shareJson: "+shareJson);
                new CustomDiaLog.Builder(context,R.style.MyDialog)
                        .setTitle("title")
                        .setMessage("这是一段小小的描述")
                        .setCancelable(false)
                        .setOnKeyListener(new DialogInterface.OnKeyListener() {
                            @Override
                            public boolean onKey(DialogInterface dialog, int keyCode, KeyEvent event) {
                                if (keyCode == KeyEvent.KEYCODE_BACK) {
                                    // 关闭 Dialog
                                    dialog.dismiss();
                                    // 关闭当前 Activity
                                    ((Activity)context).finish();
                                    // 返回 true，表示返回事件已被处理，不再向下传递
                                    return true;
                                } else {
                                    return false;
                                }
                            }
                        })
                        .show();
                return true;
            }

            /**
             * 部分自定义分享部分的实现，接收点击分享具体某个item时的回调
             * @param shareData 从H5端传递过来的分享实体
             * @return 返回true代表部分自定义，默认为false
             */
            @Override
            public boolean onShareItemClick(RsBaseShareModel shareData) {
                // 可以通过shareData对象的 convertToShareModel 转换为App需要使用的对象，入参为model的class
                AppWxMiNiProgramModel model = shareData.convertToShareModel(AppWxMiNiProgramModel.class);
                Log.e(TAG,"onShareWithShareType model: "+model);
                return false;
            }

            /**
             * 页面内的跳转，H5通过传递routerUrl的方式，回调到App端
             * @param context 上下文context
             * @param routerUrl 跳转的协议url
             */
            @Override
            public void onActionRouter(Context context, String routerUrl) {
                Log.e(TAG,"onActionRouter routerUrl: "+routerUrl);
            }

            @Override
            public void actionUrlWithFinishBlock(Context context, String url, RsFinishBlock block) {
                    Uri uri = Uri.parse(url);
                    if (TextUtils.equals(uri.getPath(),"/showQrCode")){
                        String qrUrl = uri.getQueryParameter("url");
                        Intent intent = new Intent(context,ResultActivity.class);
                        intent.putExtra("qrUrl",qrUrl);
                        context.startActivity(intent);
                        block.onFinished(OK);
                    }
            }

            @Override
            public void actionLogin(Activity activity, int requestCode) {
                Intent intent = new Intent(activity, GetUserIdActivity.class);
                activity.startActivityForResult(intent, requestCode);
            }
        });

    }
}
