package com.rushi.android.vrdemo;


import android.content.Intent;
import android.os.Bundle;
import android.os.Handler;
import android.os.Message;
import android.view.View;

import java.io.IOException;
import java.lang.ref.WeakReference;

import android.widget.TextView;
import com.google.gson.Gson;
import okhttp3.OkHttpClient;
import okhttp3.Request;
import okhttp3.Response;

public class GetUserIdActivity extends BaseActivity implements View.OnClickListener {
    private String userId = "";
    private String token = "";
    private String userName = "";
    private MessageHandler mMessageHandler;
    public static final int LOGIN_FAIL = 0;
    public static final int LOGIN_OK = 1;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_get_user_id);
        findViewById(R.id.btn_userid).setOnClickListener(this);
        mMessageHandler = new MessageHandler(this);

        updateUserInfo();
    }

    private void updateUserInfo(){
        ((TextView)findViewById(R.id.c_user_id)).setText(Utils.getUserId());
        ((TextView)findViewById(R.id.c_user_name)).setText(Utils.getUserName());
        ((TextView)findViewById(R.id.c_user_token)).setText(Utils.getAccessToken());
    }

    @Override
    public void onClick(View v) {
        Runnable getUserId = () -> {
            LoginResponse.LoginData data = null;
            String url = "https://ka-vr-demo-developer.realsee.com/demo/auth/login";
            Request request = new Request.Builder().url(url).build();
            try {
                Response response = new OkHttpClient().newCall(request).execute();
                String result = response.body().string();
                LoginResponse loginResponse = new Gson().fromJson(result,LoginResponse.class);
                if (loginResponse != null){
                    data = loginResponse.getData();
                }
            } catch (IOException e) {
                e.printStackTrace();
            }
            if (data == null){
                mMessageHandler.sendEmptyMessage(LOGIN_FAIL);
            }else{
                token = data.getToken();
                Utils.saveAccessToken(token);
                userId = data.getUser_id();
                Utils.saveUserId(userId);
                userName = data.getNickname();
                Utils.saveUserName(userName);
                mMessageHandler.sendEmptyMessage(LOGIN_OK);
            }
        };
        Thread thread = new Thread(getUserId);
        thread.start();
    }

    private void onLoginOk(){
        Intent intent = new Intent();
        intent.putExtra("userId", userId);
        intent.putExtra("token", token);
        setResult(RESULT_OK, intent);
        updateUserInfo();
        finish();
    }

    private void onLoginFail(){
        setResult(RESULT_CANCELED);
        finish();
    }


    static class MessageHandler extends Handler{
        private WeakReference<GetUserIdActivity> mWeakReferences;
        MessageHandler(GetUserIdActivity activity){
            mWeakReferences = new WeakReference<>(activity);
        }

        @Override
        public void handleMessage(Message msg) {
            if (msg.what == LOGIN_OK){
                GetUserIdActivity activity = mWeakReferences.get();
                if (activity != null){
                    activity.onLoginOk();
                }
            }else if (msg.what == LOGIN_FAIL){
                GetUserIdActivity activity = mWeakReferences.get();
                if (activity != null){
                    activity.onLoginFail();
                }
            }
        }
    }
}