package com.rushi.android.vrdemo;

import android.content.Context;
import android.content.Intent;
import android.content.pm.ActivityInfo;
import android.os.Bundle;
import android.os.Handler;
import android.os.SharedMemory;
import android.util.Log;
import android.webkit.WebView;
import android.widget.CheckBox;
import android.widget.EditText;
import android.view.View;

import android.widget.Toast;
import com.google.zxing.integration.android.IntentIntegrator;
import com.google.zxing.integration.android.IntentResult;
import com.rushi.android.vrsdk.RsVrSdk;
import com.rushi.android.vrsdk.RsVrEntity;

import static com.rushi.android.vrdemo.Utils.*;

public class MainActivity extends BaseActivity implements View.OnClickListener {

    private static final String TAG = MainActivity.class.getSimpleName();

    private EditText mUrlEditText;
    private EditText mAppIdEditText;
    private EditText mAppSecretEditText;
    private EditText mUserIdEditText;

    private CheckBox mCheckBox;

    public static final int REQUEST_JUMP_USERID = 0;
    private String token = "";
    private String userId = "";

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main_hw);
        findViewById(R.id.btn_common).setOnClickListener(this);

        mUrlEditText = findViewById(R.id.url_input);
        mUrlEditText.setText(getUrl());
        mAppIdEditText = findViewById(R.id.appid_input);
        mAppIdEditText.setText(getAppId());
        mAppSecretEditText = findViewById(R.id.appsecret_input);
        mAppSecretEditText.setText(getAppSecret());
        mUserIdEditText = findViewById(R.id.userid_input);
        mUserIdEditText.setEnabled(false);
        mUserIdEditText.setText(getUserId());

        findViewById(R.id.btn_reset_anchor).setOnClickListener(this);
        findViewById(R.id.btn_reset_audience).setOnClickListener(this);
        findViewById(R.id.btn_scan_code).setOnClickListener(this);
        findViewById(R.id.btn_jump_userid).setOnClickListener(this);

        mCheckBox = findViewById(R.id.env_checkBox);
        mCheckBox.setOnClickListener(this);
        mCheckBox.setChecked(isTest());
        WebView.setWebContentsDebuggingEnabled(true);
    }
    @Override
    public void onClick(View v) {
        switch (v.getId()) {
            case R.id.btn_common: // 进入测试页面
                commonTest();
                break;
            case R.id.btn_reset_anchor: // 恢复默认主持人链接
                {
                    mUrlEditText.setText(DEFAULT_URL);
                }
                break;
            case R.id.btn_reset_audience: // 恢复默认观众链接
            {
                mUrlEditText.setText(DEFAULT_URL);
            }
            break;
            case R.id.btn_scan_code: // 扫码获取链接
                {
                    scanQrCode();
                }
                break;
            case R.id.env_checkBox: // 改变测试环境
                {
                    checkTest(mCheckBox.isChecked());
                }
                break;
            case R.id.btn_jump_userid: // 获取userId
            {
                Intent intent = new Intent(MainActivity.this, GetUserIdActivity.class);
                startActivityForResult(intent, REQUEST_JUMP_USERID);
            }
                break;
        }
    }

    private void scanQrCode() {
        IntentIntegrator integrator = new IntentIntegrator(MainActivity.this);
        // 设置要扫描的条码类型，ONE_D_CODE_TYPES：一维码，QR_CODE_TYPES-二维码
        integrator.setDesiredBarcodeFormats(IntentIntegrator.QR_CODE);
        integrator.setPrompt("扫描VR URL");
        integrator.setCameraId(0);  // Use a specific camera of the device
        integrator.setBeepEnabled(true);
        integrator.setBarcodeImageEnabled(false);
        integrator.setOrientationLocked(true);
        integrator.initiateScan();
    }

    @Override
    protected void onActivityResult(int requestCode, int resultCode, Intent data) {
        IntentResult result = IntentIntegrator.parseActivityResult(requestCode, resultCode, data);
        if(result != null) {
            if(result.getContents() == null) {
                Toast.makeText(this, "取消扫描", Toast.LENGTH_SHORT).show();
            } else {
                String resultStr = result.getContents();
                Toast.makeText(this, "扫描结果为: " + resultStr, Toast.LENGTH_SHORT).show();
                mUrlEditText.setText(resultStr);
            }
            return;
        }
        super.onActivityResult(requestCode, resultCode, data);
        if (requestCode == REQUEST_JUMP_USERID && resultCode == RESULT_OK) {
            userId = data.getStringExtra("userId");
            token = data.getStringExtra("token");
            mUserIdEditText.setText(userId);
        }
    }

    // 打开VR
    private void commonTest() {
        // 保存页面设置项
        String url = mUrlEditText.getText().toString();
        saveUrl(url);
        String appId = mAppIdEditText.getText().toString();
        saveAppId(appId);
        String appSecret = mAppSecretEditText.getText().toString();
        saveAppSecret(appSecret);
        String userId = mUserIdEditText.getText().toString();
        saveUserId(userId);
        saveAccessToken(token);
        String coverUrl = "http://vrlab-public.ljcdn.com//release//vradmin//1000000020129136//images//FF41C450.png";
        RsVrEntity vrEntity = new RsVrEntity(url)
            .setCoverUrl(coverUrl)
            .setLogoUrl(coverUrl)
            .setHideLoadingProgress(true)
                .setOrientation(ActivityInfo.SCREEN_ORIENTATION_PORTRAIT);
        RsVrSdk.openVr(this, vrEntity);

        Context ctx = this;
        new Thread(new Runnable() {
            @Override
            public void run() {
                try {
                    Thread.sleep(3000);
                    RsVrSdk.closeVr(ctx);
                } catch (InterruptedException e) {
                    throw new RuntimeException(e);
                }

            }
        }).start();
    }

}
